# ------------------------------------------------------------------------------
# dollar

foo$bar
foo$bar$baz
foo$bar@baz
foo$bar()
foo$"bar"
foo$bar()$baz[[1]]$bam
foo$...
foo$..1

# ------------------------------------------------------------------------------
# dollar no rhs

foo$

# ------------------------------------------------------------------------------
# slot

foo@bar
foo@bar$baz
foo@bar()
foo@"bar"
foo@...
foo@..1

# ------------------------------------------------------------------------------
# slot no rhs

foo@
